.. _tutorials:

Tutorials
=========

.. note::

    The tutorial is based on `Odoo 10.0`, the examples must be adapted
    following the version of `Odoo` you are using.

.. toctree::
    :maxdepth: 2

    tuto_create_db
    tuto_login
    tuto_rpc_queries
    tuto_browse
    tuto_browse_methods
    tuto_browse_update
    tuto_report
    tuto_session

